# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot


snapshots = Snapshot()

snapshots['test_schema_error[error-nonexistent] 1'] = {
    'data': {
        'allProductTypes': {
            'edges': [
                {
                    'node': {
                        'name': 'map',
                        'typeId': '1'
                    }
                },
                {
                    'node': {
                        'name': 'beam',
                        'typeId': '2'
                    }
                }
            ]
        }
    }
}

snapshots['test_schema_error[error-unempty] 1'] = {
    'data': {
        'allProductTypes': {
            'edges': [
                {
                    'node': {
                        'name': 'map',
                        'typeId': '1'
                    }
                },
                {
                    'node': {
                        'name': 'beam',
                        'typeId': '2'
                    }
                }
            ]
        }
    }
}

snapshots['test_schema_success[delete] 1'] = {
    'data': {
        'deleteProductType': {
            'ok': True
        }
    }
}

snapshots['test_schema_success[delete] 2'] = {
    'data': {
        'allProductTypes': {
            'edges': [
                {
                    'node': {
                        'name': 'map',
                        'typeId': '1'
                    }
                }
            ]
        }
    }
}



from pathlib import Path
import git

import pytest


##__________________________________________________________________||
@pytest.fixture()
def folder(tmpdir_factory):
    """path to an folder (not a git repo) with two text files

    f.txt
       abc

    g.txt
       123

    """
    folder = Path(tmpdir_factory.mktemp("git"))
    file1 = folder.joinpath("f.txt")
    file2 = folder.joinpath("g.txt")
    file1.write_text("abc\n")
    file2.write_text("123\n")
    yield folder


##__________________________________________________________________||
@pytest.fixture()
def repo(folder):
    """a git repo

    The folder is initialized as a git repo.
    The two files in the folder are committed.


    """
    repo = git.Repo.init(folder)
    repo.git.add(A=True)
    repo.index.commit("initial commit")
    yield repo


##__________________________________________________________________||
@pytest.fixture()
def bare_repo(repo, tmpdir_factory):
    """a bare repo, a clone of the repo"""
    folder = Path(tmpdir_factory.mktemp("git"))
    y = git.Repo.clone_from(repo.working_tree_dir, folder, bare=True)
    yield y


@pytest.fixture()
def github_repo_url(bare_repo, tmpdir_factory):
    """a factory fixture"""
    url = "git@github.com:TaiSakuma/fuzzy-garbanzo.git"

    def _f():
        """create a clone of the bare repo and push force
        the content to the github repo

        """
        folder = Path(tmpdir_factory.mktemp("git"))
        clone = git.Repo.clone_from(bare_repo.git_dir, folder)
        branch_name = clone.active_branch.name
        remote = clone.create_remote("github", url=url)
        remote.push(refspec=f"{branch_name}:{branch_name}", force=True)
        return url

    yield _f


@pytest.fixture(
    params=[
        "local_folder",
        # 'github_repo'
    ]
)
def remote_url(request, bare_repo, github_repo_url):
    p = request.param
    if p == "local_folder":
        y = bare_repo.git_dir
    elif p == "github_repo":
        y = github_repo_url()
    else:
        raise ValueError(f"unknown param: {p}")
    yield y


##__________________________________________________________________||



"""rename a column name in account_admins

Revision ID: 4c32365bb655
Revises: e1d390d440d5
Create Date: 2021-02-14 20:27:23.992720

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '4c32365bb655'
down_revision = 'e1d390d440d5'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('account_admins', schema=None) as batch_op:
        batch_op.alter_column('github_login', new_column_name='git_hub_login', existing_type=sa.Text())
        # batch_op.add_column(sa.Column('git_hub_login', sa.Text(), nullable=False))
        # batch_op.drop_constraint('uq_account_admins_github_login', type_='unique')
        # batch_op.create_unique_constraint(batch_op.f('uq_account_admins_git_hub_login'), ['git_hub_login'])
        # batch_op.drop_column('github_login')

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('account_admins', schema=None) as batch_op:
        batch_op.alter_column('git_hub_login', new_column_name='github_login', existing_type=sa.Text())
        # batch_op.add_column(sa.Column('github_login', sa.TEXT(), nullable=False))
        # batch_op.drop_constraint(batch_op.f('uq_account_admins_git_hub_login'), type_='unique')
        # batch_op.create_unique_constraint('uq_account_admins_github_login', ['github_login'])
        # batch_op.drop_column('git_hub_login')

    # ### end Alembic commands ###
